Version 1.1 (June 29, 2020)
===================

This version adds more documentation

Version 1.0 (May 07, 2020)
==========================

This is the first major release of the software, in tandem with the appearance
of the preprint about the method.


